@@ -6,7 +6,7 @@
 ;;         MORIOKA Tomohiko <morioka@jaist.ac.jp>
 ;; Maintainer: MORIOKA Tomohiko <morioka@jaist.ac.jp>
 ;; Created: 1994/08/21 renamed from mime.el
-;; Version: $Revision: 1.6 $
+;; Version: $Revision: 1.7 $
 ;; Keywords: mail, news, MIME, multimedia, multilingual
 
 ;; This file is part of tm (Tools for MIME).
@@ -120,7 +120,7 @@
 ;;;
 
 (defconst mime-editor/RCS-ID
-  "$Id: tm-edit.el,v 1.6 2000/09/04 06:51:02 martinb Exp $")
+  "$Id: tm-edit.el,v 1.7 2000/10/06 09:16:04 youngs Exp $")
 
 (defconst mime-editor/version (get-version-string mime-editor/RCS-ID))
 
@@ -371,7 +371,7 @@ If encoding is nil, it is determined from its contents.")
 
 (defvar mime-editor/transfer-level-string
   (mime/encoding-name mime-editor/transfer-level 'not-omit)
-  "*A string formatted version of mime/defaul-transfer-level")
+  "*A string formatted version of mime/default-transfer-level")
 (make-variable-buffer-local 'mime-editor/transfer-level-string)
 
 (defun mime-editor/make-charset-default-encoding-alist (transfer-level)
